@@ -34,7 +34,7 @@ ggplot2::autoplot
 #' @param points_per_min_cycle_length Used to determine the number of samples
 #' to create plot if \code{pred.length.out} is missing.
 #' @param ranef_plot Specify the random effects variables that you wish to plot.
-#'  If not specified, only the fixed effects will be visualised.
+#'  If not specified, only the fixed effects will be visualized.
 #' @param quietly A \code{logical}. If \code{TRUE}, shows warning messages when
 #' wrangling data and fitting model. Defaults to \code{TRUE}.
 #' @param cov_list Specify the levels of the covariates that you wish to plot as
@@ -293,12 +293,27 @@ autoplot.cglmm <- function(object,
       newdata[, j] <- factor(ref_level)
     }
     # process the data. This step mimics the first step of a cglmm() call
-    newdata <- update_formula_and_data(
-      # pass new dataset that's being used for prediction in this function
+
+    # add disp/zi formulas if they are used
+    newdata_args <- list(
       data = newdata,
-      # get the formula that was originally to cglmm()
       formula = eval(x$cglmm.calls$cglmm$formula)
-    )$newdata
+    )
+    if (x$dispformula_used) {
+      newdata_args <- c(
+        newdata_args,
+        dispformula = x$cglmm.calls$cglmm$dispformula
+      )
+    }
+    if (x$ziformula_used) {
+      newdata_args <- c(
+        newdata_args,
+        ziformula = x$cglmm.calls$cglmm$ziformula
+      )
+    }
+
+    newdata <- do.call(update_formula_and_data, newdata_args)$newdata
+
     # only keep the newdata that's returned from update_formula_and_data()
 
     if (!is.null(ranef_plot)) {
@@ -318,17 +333,28 @@ autoplot.cglmm <- function(object,
       }
 
       newdata$levels <- ""
-      i <- 1 # used as a counter for formatting purposes
-      for (d in x_str) {
+      if (length(x_str) == 1) {
         newdata$levels <- paste0(
           newdata$levels,
-          d, "=", newdata[, d]
+          newdata[, x_str]
         )
-        # if there are multiple group levels, separate them by "|"
-        if (i < length(x_str)) {
-          newdata$levels <- paste0(newdata$levels, " | ")
+      }
+
+      i <- 1 # used as a counter for formatting purposess
+      if (length(x_str) > 1) {
+        for (d in x_str) {
+          newdata$levels <- paste0(
+            newdata$levels,
+            d,
+            "=",
+            newdata[, d]
+          )
+          # if there are multiple group levels, separate them by "|"
+          if (i < length(x_str)) {
+            newdata$levels <- paste0(newdata$levels, " | ")
+          }
+          i <- i + 1
         }
-        i <- i + 1
       }
     }
 
@@ -416,7 +442,6 @@ autoplot.cglmm <- function(object,
     }
   }
 
-  #
   newdata_processed <- data_processor_plot(object, newdata, x_str)
 
   # get the response data from the cglmm object
@@ -438,12 +463,16 @@ autoplot.cglmm <- function(object,
   y_min <- pred_obj$fit - zt * pred_obj$se.fit
   y_max <- pred_obj$fit + zt * pred_obj$se.fit
 
+  if (!is.null(x_str)) {
+    if (length(x_str) == 1) {
+      x_str_label <- x_str
+    } else {
+      x_str_label <- "Groups"
+    }
+  }
   # get the original data from the cglmm object to be superimposed
 
-
   ##
-
-
   if (any(!is.na(object$ranef_groups))) {
     if (superimpose.data) {
       original_data <- object$newdata
@@ -456,8 +485,6 @@ autoplot.cglmm <- function(object,
       for (d in x_str) {
         original_data_processed$levels <- paste0(
           original_data_processed$levels,
-          d,
-          "=",
           original_data_processed[, d]
         )
         # if there are multiple group levels, separate them by "|"
@@ -469,7 +496,6 @@ autoplot.cglmm <- function(object,
         i <- i + 1
       }
     }
-
     # generating the plots
     if (!is.null(ranef_plot)) {
       if (missing(x_str) || is.null(x_str)) {
@@ -582,8 +608,6 @@ autoplot.cglmm <- function(object,
       for (d in x_str) {
         original_data_processed$levels <- paste0(
           original_data_processed$levels,
-          d,
-          "=",
           original_data_processed[, d]
         )
         # if there are multiple group levels, separate them by "|"
@@ -615,7 +639,8 @@ autoplot.cglmm <- function(object,
               y = !!rlang::sym(y_name),
               col = levels
             )
-          )
+          ) +
+          ggplot2::labs(col = x_str_label)
       }
     }
 
@@ -658,6 +683,7 @@ autoplot.cglmm <- function(object,
             ),
             alpha = data_opacity
           ) +
+          ggplot2::labs(col = x_str_label) +
           ggplot2::facet_grid(rows = ggplot2::vars(NULL))
       }
     }
@@ -689,6 +715,8 @@ autoplot.cglmm <- function(object,
             ),
             alpha = 0.5
           ) +
+          ggplot2::labs(fill = x_str_label) +
+          ggplot2::labs(col = x_str_label) +
           ggplot2::facet_grid(rows = ggplot2::vars(NULL))
       }
     }
